==> jonas-JONAS_5_0_5.tar: jonas-JONAS_5_0_5/modules/ee-components/jonas-admin/src/main/java/org/ow2/jonas/webapp/jonasadmin/resource/ApplyDestinationAction.java <==
/*
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id:
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.webapp.jonasadmin.resource;

import java.io.IOException;

import javax.management.ObjectName;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.ow2.jonas.lib.util.JonasObjectName;
import org.ow2.jonas.webapp.jonasadmin.JonasManagementRepr;
import org.ow2.jonas.webapp.jonasadmin.WhereAreYou;
import org.ow2.jonas.webapp.jonasadmin.deploy.BaseDeployAction;

import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;



/**
 * @author Adriana Danes
 * Creation of new destinations
 */

public class ApplyDestinationAction extends BaseDeployAction {

// --------------------------------------------------------- Public Methods

    public ActionForward executeAction(ActionMapping p_Mapping, ActionForm p_Form
        , HttpServletRequest p_Request, HttpServletResponse p_Response)
        throws IOException, ServletException {

        // Current server
        String serverName = m_WhereAreYou.getCurrentJonasServerName();
        String domainName = m_WhereAreYou.getCurrentDomainName();

        // Form used
        DestinationForm oForm = (DestinationForm) p_Form;

        try {
            String name = oForm.getName();
            // Create a Jms destination
            // -- create a queue for the moment --
            ObjectName oObjectName = JonasObjectName.jmsService(domainName);
            String[] asParam = {
                    oForm.getName()
            };
            String[] asSignature = {
                    "java.lang.String"
            };
            String type = oForm.getType();
            if (type.equals(m_Resources.getMessage("label.resource.destinations.queue")))
                JonasManagementRepr.invoke(oObjectName, "createJmsQueueDestination", asParam, asSignature, serverName);
            else if (type.equals(m_Resources.getMessage("label.resource.destinations.topic")))
                JonasManagementRepr.invoke(oObjectName, "createJmsTopicDestination", asParam, asSignature, serverName);

            // refresh tree
            refreshServiceTree(WhereAreYou.DEPLOYMENT_JMS, p_Request);

            oForm.reset(p_Mapping, p_Request);

        } catch (Throwable t) {
            addGlobalError(t);
            saveErrors(p_Request, m_Errors);
            return (p_Mapping.findForward("Global Error"));
        }

        // Forward to the jsp.
        return (p_Mapping.findForward("Create Destination"));
    }
}

==> jonas-JONAS_5_1_1.tar: jonas-JONAS_5_1_1/modules/ee-components/jonas-admin/src/main/java/org/ow2/jonas/webapp/jonasadmin/resource/ApplyDestinationAction.java <==
/*
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id:
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.webapp.jonasadmin.resource;

import java.io.IOException;

import javax.management.ObjectName;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.ow2.jonas.lib.management.extensions.base.JonasManagementRepr;
import org.ow2.jonas.lib.util.JonasObjectName;
import org.ow2.jonas.webapp.jonasadmin.WhereAreYou;
import org.ow2.jonas.webapp.jonasadmin.deploy.BaseDeployAction;

import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;



/**
 * @author Adriana Danes
 * Creation of new destinations
 */

public class ApplyDestinationAction extends BaseDeployAction {

// --------------------------------------------------------- Public Methods

    public ActionForward executeAction(ActionMapping p_Mapping, ActionForm p_Form
        , HttpServletRequest p_Request, HttpServletResponse p_Response)
        throws IOException, ServletException {

        // Current server
        String serverName = m_WhereAreYou.getCurrentJonasServerName();
        String domainName = m_WhereAreYou.getCurrentDomainName();

        // Form used
        DestinationForm oForm = (DestinationForm) p_Form;

        try {
            String name = oForm.getName();
            // Create a Jms destination
            // -- create a queue for the moment --
            ObjectName oObjectName = JonasObjectName.jmsService(domainName);
            String[] asParam = {
                    oForm.getName()
            };
            String[] asSignature = {
                    "java.lang.String"
            };
            String type = oForm.getType();
            if (type.equals(m_Resources.getMessage("label.resource.destinations.queue")))
                JonasManagementRepr.invoke(oObjectName, "createJmsQueueDestination", asParam, asSignature, serverName);
            else if (type.equals(m_Resources.getMessage("label.resource.destinations.topic")))
                JonasManagementRepr.invoke(oObjectName, "createJmsTopicDestination", asParam, asSignature, serverName);

            // refresh tree
            refreshServiceTree(WhereAreYou.DEPLOYMENT_JMS, p_Request);

            oForm.reset(p_Mapping, p_Request);

        } catch (Throwable t) {
            addGlobalError(t);
            saveErrors(p_Request, m_Errors);
            return (p_Mapping.findForward("Global Error"));
        }

        // Forward to the jsp.
        return (p_Mapping.findForward("Create Destination"));
    }
}
